@@ -8,6 +8,7 @@ __all__ = ['activation',
            'feedforward',
            'loss',
            'gradient',
-           'optimizer']
+           'optimizer',
+           'load']
 
 from phidnet import *
\ No newline at end of file
